[java-identity-provider COMMIT] in /trunk/idp-attribute-filter-impl/src/test/java/net/shibboleth/idp/attribute/filter...

noreply at shibboleth.net noreply at shibboleth.net
Tue Sep 6 11:31:39 BST 2011


Author: rdw
Date: Tue Sep  6 11:31:39 2011
New Revision: 4056

URL: http://svn.shibboleth.net/view/java-identity-provider?rev=4056&view=rev
Log:
Comments and test method names showed a touch of cut and paste

Modified:
    trunk/idp-attribute-filter-impl/src/test/java/net/shibboleth/idp/attribute/filtering/impl/policy/TestAuthenticationMethodRegex.java
    trunk/idp-attribute-filter-impl/src/test/java/net/shibboleth/idp/attribute/filtering/impl/policy/TestAuthenticationMethodString.java

Modified: trunk/idp-attribute-filter-impl/src/test/java/net/shibboleth/idp/attribute/filtering/impl/policy/TestAuthenticationMethodRegex.java
URL: http://svn.shibboleth.net/view/java-identity-provider/trunk/idp-attribute-filter-impl/src/test/java/net/shibboleth/idp/attribute/filtering/impl/policy/TestAuthenticationMethodRegex.java?rev=4056&r1=4055&r2=4056&view=diff
==============================================================================
--- trunk/idp-attribute-filter-impl/src/test/java/net/shibboleth/idp/attribute/filtering/impl/policy/TestAuthenticationMethodString.java (original)
+++ trunk/idp-attribute-filter-impl/src/test/java/net/shibboleth/idp/attribute/filtering/impl/policy/TestAuthenticationMethodString.java Tue Sep  6 11:31:39 2011
@@ -34,7 +34,7 @@
      * @throws ComponentInitializationException never
      */
     @Test
-    public void principalNameCriterionTest() throws EvaluationException, ComponentInitializationException {
+    public void autheticationMethodStringCriterionTest() throws EvaluationException, ComponentInitializationException {
 
         AttributeFilterContext filterContext = new AttributeFilterContext(new TestContextContainer());
         AuthenticationMethodStringCriterion filter = new AuthenticationMethodStringCriterion();



More information about the commits mailing list
--- trunk/idp-attribute-filter-impl/src/test/java/net/shibboleth/idp/attribute/filtering/impl/policy/TestAuthenticationMethodRegex.java (original)
+++ trunk/idp-attribute-filter-impl/src/test/java/net/shibboleth/idp/attribute/filtering/impl/policy/TestAuthenticationMethodRegex.java Tue Sep  6 11:31:39 2011
@@ -28,13 +28,13 @@
 public class TestAuthenticationMethodRegex {
 
     /**
      * Test principal name matching. Parameterization is tested in other tests.
      * 
      * @throws EvaluationException to keep the compiler happy.
      * @throws ComponentInitializationException never
      */
     @Test
-    public void principalNameCriterionTest() throws EvaluationException, ComponentInitializationException {
+    public void autheticationMethodRegexCriterionTest() throws EvaluationException, ComponentInitializationException {
 
         AttributeFilterContext filterContext = new AttributeFilterContext(new TestContextContainer());
         AuthenticationMethodRegexCriterion filter = new AuthenticationMethodRegexCriterion();
@@ -28,13 +28,13 @@
 
     /**
-     * Test principal name matching. Parameterization is tested in other tests.
+     * Test authentication method matching. Parameterization is tested in other tests.
      * 
      * @throws EvaluationException to keep the compiler happy.

Modified: trunk/idp-attribute-filter-impl/src/test/java/net/shibboleth/idp/attribute/filtering/impl/policy/TestAuthenticationMethodString.java
URL: http://svn.shibboleth.net/view/java-identity-provider/trunk/idp-attribute-filter-impl/src/test/java/net/shibboleth/idp/attribute/filtering/impl/policy/TestAuthenticationMethodString.java?rev=4056&r1=4055&r2=4056&view=diff
==============================================================================